Crate retch_cli

Crate retch_cli 

retch

A fast, feature-rich system information fetcher written in Rust. Similar to tools like fastfetch or neofetch.

This crate provides both a CLI binary (retch) and a library interface for fetching and displaying system information.

Modules

cli
Command-line interface definitions.
config
Configuration management and parsing.
display
Formatting and display logic for terminal output.
fetch
System information gathering.
fields
Single source of truth for the set of displayable fields and their output strata.
gpu
GPU detection and identification.
logo
ASCII and graphical logo definitions and rendering.
theme
Color theming and styling.
weather