Command-line interface definitions.
Defines the CLI arguments, flags, and options using the clap crate.
Structs
- Cli
- Command-line arguments for retch.
Enums
- Completion
Shell - Supported shells for completion generation.
Command-line interface definitions.
Defines the CLI arguments, flags, and options using the clap crate.