pub fn logo_cells_for(img_w: u32, img_h: u32) -> LogoFitExpand description
Returns the cell footprint an image will occupy on the current terminal.
Thin wrapper pairing terminal_cell_size_px with the pure fit_logo_cells.
pub fn logo_cells_for(img_w: u32, img_h: u32) -> LogoFitReturns the cell footprint an image will occupy on the current terminal.
Thin wrapper pairing terminal_cell_size_px with the pure fit_logo_cells.