print_with_chafa

Function print_with_chafa 

pub fn print_with_chafa(path: &Path) -> bool
Attempts to render an image using the chafa utility.

Chafa renders images using high-quality Unicode symbols, providing a good graphical fallback for many terminal emulators.