Module logo

Module logo 

ASCII and graphical logo definitions and rendering.

Contains embedded distro logos and logic for rendering them as text or images (e.g., Sixel, Kitty, iTerm).

Functions

chafa_available
Checks if the chafa command-line tool is available in the system path.
detect_distro
Attempts to detect the current operating system distribution.
get_ascii_logo
Returns a list of strings representing the ASCII art for a given distro.
get_embedded_logo
Returns the raw PNG bytes for an embedded distro logo.
print_distro_logo
Print logo for a distro following the strict priority:
print_distro_logo_with_ascii
Renders the distribution logo with an option to force ASCII mode.
print_graphical_logo
Renders a raw image buffer using the Kitty graphics protocol.
print_graphical_logo_from_path
Loads an image from a file, resizes it, and prints it using the graphics protocol.
print_iterm2_logo
Renders a raw image buffer using the iTerm2 inline image protocol.
print_iterm2_logo_from_path
Loads an image from a file and prints it using the iTerm2 protocol.
print_sixel_logo
Renders a raw image buffer (e.g. PNG bytes) using the Sixel graphics protocol.
print_sixel_logo_from_path
Loads an image from a file, resizes it, and prints it using the Sixel protocol.
print_sixel_rgba
Renders raw RGBA pixels using the Sixel graphics protocol.
print_with_chafa
Attempts to render an image using the chafa utility.
supports_iterm2
Checks if the terminal supports the iTerm2 inline image protocol.
supports_kitty
Checks if the terminal supports the Kitty inline image protocol.
supports_sixel
Checks if the terminal supports Sixel graphics (heuristic based on environment).