ASCII and graphical logo definitions and rendering.
Contains embedded distro logos and logic for rendering them as text or images (e.g., Sixel, Kitty, iTerm).
Functions
- chafa_
available - Checks if the
chafacommand-line tool is available in the system path. - detect_
distro - Attempts to detect the current operating system distribution.
- get_
ascii_ logo - Returns a list of strings representing the ASCII art for a given distro.
- get_
embedded_ logo - Returns the raw PNG bytes for an embedded distro logo.
- print_
distro_ logo - Print logo for a distro following the strict priority:
- print_
distro_ logo_ with_ ascii - Renders the distribution logo with an option to force ASCII mode.
- print_
graphical_ logo - Renders a raw image buffer using the Kitty graphics protocol.
- print_
graphical_ logo_ from_ path - Loads an image from a file, resizes it, and prints it using the graphics protocol.
- print_
iterm2_ logo - Renders a raw image buffer using the iTerm2 inline image protocol.
- print_
iterm2_ logo_ from_ path - Loads an image from a file and prints it using the iTerm2 protocol.
- print_
sixel_ logo - Renders a raw image buffer (e.g. PNG bytes) using the Sixel graphics protocol.
- print_
sixel_ logo_ from_ path - Loads an image from a file, resizes it, and prints it using the Sixel protocol.
- print_
sixel_ rgba - Renders raw RGBA pixels using the Sixel graphics protocol.
- print_
with_ chafa - Attempts to render an image using the
chafautility. - supports_
iterm2 - Checks if the terminal supports the iTerm2 inline image protocol.
- supports_
kitty - Checks if the terminal supports the Kitty inline image protocol.
- supports_
sixel - Checks if the terminal supports Sixel graphics (heuristic based on environment).