Module theme

Module theme 

Color theming and styling.

Defines color palettes and provides functionality for applying colors to the output text.

Structs

Theme
A collection of colors used for terminal output.

Functions

parse_color
Parse a color name or hex string into an RGB value.